Foundry: Sorkin Type Co

Merriweather was designed to be a text face that is pleasant to read on screens.

Merriweather is an evolving project and will be updated. As of now there are 4 styles: Regular, Light, Bold, and Black. There are now Italic styles in each of these weights, too.

There is also Merriweather Sans, a sans-serif version which closely harmonizes with the weights and styles of this serif family.

Designed by Eben Sorkin, Merriweather features a very large x height, slightly condensed letterforms, a mild diagonal stress, sturdy serifs and open forms.

Merriweather is a work in progress and will be improved regularly. This means you can request improvements and even fund specific features if if they are outside of the current scope of work. For more information and to stay updated see Eben Sorkin's blog and Flickr stream, and the MerriweatherFnt Twitter microblog.

Updated in May 2013: Merriweather has been updated with a larger character set, and Italic styles have been added for all weights. (As one of the earliest families published in Google Web Fonts, Merriweather lacked proper subsetting, so this update introduces a default 'latin' subset that contains less characters, but loads faster. To use the full character set, update your API link to include the 'latin-ext' subset.)

Updated in January 2016: A deep refresh of the design that makes all upright or roman styles darker, to improve on-screen rendering especially at text sizes with ttfautohint hinting. Merriweather now supports Cyrillic, and will work better when installed on desktops. Some OpenType features were added and improved. Since the vertical and horizontal metrics changed, this may cause some text to reflow in some browsers. A second minor update (v1.583) was made on January 25th to fix ligatures and other digraphs. A third minor update (v1.584) was made on February 3rd to fix digraphcs in the Regular and improve the Cyrillic hinting.